@@ -19,10 +19,14 @@
 Useful shapes to decorate MeshCat scenes.
 """
 
-__version__ = "0.1.0"
+__version__ = "0.3.0"
 
 from .frame import frame
+from .point import point
+from .textarea import textarea
 
 __all__ = [
     "frame",
+    "point",
+    "textarea",
 ]
